Skip to contents

Gene annotations in hgnc and ensembl format. Features, for the classifier relevant genes. For convenience, both formats are available for seamless conversion of IDs, regardless of the format of the incoming data.

Usage

data(gene_list)

Format

A data frame with 1900 rows (genes) and 2 columns (hgnc_symbol and ensembl_gene_id).

Details

A data frame with gene information in different formats.

  • ensembl_gene_id. Gene annotation in ensembl format.

  • hgnc_symbol. Gene annotation in HUGO format.