Skip to contents

This function bins all numeric variables in a data frame into a specified number of bins.

Usage

int_bin_numeric_variables(this_data = NULL, num_bins = NULL)

Arguments

this_data

Required. A data frame containing the data to be binned.

num_bins

Required. The number of bins to use for binning the numeric variables.

Value

A data frame with the numeric variables binned into the specified number of bins.

Details

Internal function. Not meant for out-of-package use. The function identifies all numeric columns in the provided data frame and applies a binning process to each numeric column. The binning process divides the range of each numeric column into a specified number of bins and assigns each value to one of these bins.

Examples

if (FALSE) { # \dontrun{
# No examples provided
} # }