Skip to contents

Check score ties between predictions scores.

Usage

int_check_ties(first, last)

Arguments

first

Predictions when setting ties.method = "first"

last

Predictions when setting ties.method = "last"

Value

Nothing.

Details

Internal function called by int_calc_signatures(). Not meant for out of package use. Checks score ties in the prediction scores and prints a message indicating the sample where the tie occurred, the two subtypes with the tied scores and the subtype that is reported in the output object.

Examples

if (FALSE) { # \dontrun{
# No examples provided
} # }