Skip to contents

Internal function called by plot_hm_scores when proportional_scores = TRUE. Not meant for out-of-package usage.

Usage

int_get_prop_scores(these_predictions = NULL)

Arguments

these_predictions

A list containing a data frame named scores with prediction scores. The data frame should have row names as sample IDs and columns corresponding to different cell types and scores.

Value

A data frame with the original scores, normalized scores, and the calculated immune/stroma ratio. The row names are the sample IDs.

Details

This function normalizes specific prediction scores so that each value is a fraction of the total score for that row. It also calculates the immune/stroma ratio.

Examples

if (FALSE) { # \dontrun{
# No examples provided
} # }