LundTax2023
LundTaxR-package.RdThis packages implements a Random Forest rule-based single-sample predictor that classifies transcriptomic samples into the 5 (or 7, including subclasses) Lund Taxonomy molecular subtypes. The final classifier is composed of two separate predictors applied sequentially: first a sample is classified as one of the 5 main classes (Uro, GU, BaSq, Mes or ScNE), and then samples classified as Uro are subclassified into UroA, UroB or UroC by a second predictor
Author
Maintainer: Adam Mattsson adam.mattsson@med.lu.se
Authors:
Elena Aramendía elena.aramendia_cotillas@med.lu.se
Pontus Eriksson pontus.eriksson@med.lu.se