Classifier LundTax 7c.
classifier_lundtax_7c.RdClassifier as a rule_based_RandomForest object. Predicts samples as one of the 3 Uro subclasses,
UroA, UroB, or UroC. Object includes the final RF classifier, the used genes and rules in the
final model, the Boruta results, and the training matrix. The training matrix is a binary matrix
containing the rule values for the training data and it is used for imputation purposes during
the prediction if values are missing in the sample. This object was generated using the
multiclassPairs::predict_RF() function.
Usage
data(classifier_lundtax_7c)Details
A Large rule_based_RandomForest object. A list of 6.
genes. Genes in hgnc format.
rules. A set of rules for the classifier in hgnc format.
TrainingMatrix. Binary matrix for the rules in the training data.
boruta. Boruta results for the classifier.
RF_classifier. Random forest classifier details.
calls. Information on how the model was generated.