Check Ties Between prediction Scores
int_check_ties.RdCheck score ties between predictions scores.
Details
Internal function called by int_calc_signatures().
Not meant for out of package use. Checks score ties in the prediction scores and prints a message
indicating the sample where the tie occurred, the two subtypes with the tied scores and the
subtype that is reported in the output object.