Calculate Signature Ratio Scores
int_ratio_score.RdCalculate proliferation and progression scores.
Arguments
- this_data
Required parameter. Data frame or matrix with expression values.
- variable
Required parameter. Input should be one of the following; proliferation, or progression.
- gene_id
Specify the type of gene identifier used in
this_data. Accepted values are; hgnc_symbol (default) or ensembl_gene_id.- verbose
A logical value indicating whether processing messages will be printed or not. Default is TRUE.
Value
A list with two objects. 1, A data frame with scores for the selected variable. 2, A data frame indicating what genes from the incoming data are missing, based on the expected genes for signature calculations.
Details
Internal function called by int_calc_signatures().
Not meant for out of package use. Takes a data frame of matrix with expression values and
calculates scores based on gene expression.